@@ -307,12 +307,6 @@ class Payer(BaseModel):
         validate_all = True
         validate_assignment = True
 
-    @validator('country')
-    def country_must_be_it(cls, v):
-        if 'IT' not in v:
-            raise ValidationError('country must be IT')
-        return v
-
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
 
