@@ -157,6 +157,14 @@ class PaymentTestCase(TestCase):
         # Asserzione per l'attributo app_id
         self.assertEqual(payment.app_id, 'mypay-payment-proxy:1.8.0')
 
+    def test_payer_creation(self):
+        payer = Payer(**get_payer_data())
+        self.assertEqual(payer.type, PayerType.TYPE_HUMAN)
+        self.assertEqual(payer.tax_identification_number, 'SLVLNZ76P01G843V')
+        self.assertEqual(payer.name, 'Lorenzo')
+        self.assertEqual(payer.family_name, 'Salvadorini')
+        self.assertEqual(payer.email, 'raffaele.luccisano@opencontent.it')
+
     def test_payment_reason_length(self):
         with self.assertRaises(ValidationError):
             Payment(
@@ -233,10 +241,6 @@ class PaymentTestCase(TestCase):
             self.assertEqual(payment.links.update.next_check_at, None)
             self.assertEqual(payment.status, PaymentStatus.STATUS_EXPIRED)
 
-    def test_payer_country(self):
-        with self.assertRaises(ValidationError):
-            Payer(**get_payer_data(country='XX'))
-
     def test_encoders(self):
         payment = Payment(**get_payment_event_data())
 
@@ -503,4 +507,4 @@ class PaymentTestCase(TestCase):
         self.assertIsInstance(payload['amount'], (int, float))
         self.assertEqual(payload['amount'], 0.01)
         self.assertEqual(payload['code'], 'SER')
-        self.assertEqual(payload['meta'], {'x': True})
\ No newline at end of file
+        self.assertEqual(payload['meta'], {'x': True})
